==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+47"/>
        <source>Status Bar Font:</source>
        <translation>Fuente barra de estado:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>Widgets en la barra de estado</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>Pantalla de coordenadas</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>Pantalla del ratón</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>Pantalla de la Selección</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>Pantalla del progreso</translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>Barra de estado</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>Barra de &amp;estado</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+53"/>
        <source>Status Bar Font:</source>
        <translation>Fuente barra de estado:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>Widgets en la barra de estado</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>Pantalla de coordenadas</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>Pantalla del ratón</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>Pantalla de la Selección</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>Pantalla del progreso</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Show status tips</source>
        <translation>Mostrar sugerencias de estado</translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>Barra de estado</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>Barra de &amp;estado</translation>
    </message>
</context>
</TS>
